@@ -86,7 +86,7 @@
 
 /*
  *      @(#)netdb.h	8.1 (Berkeley) 6/2/93
- *	$Id: netdb.h,v 1.12.2.1.4.5 2004/11/30 01:15:42 marka Exp $
+ *	$Id: netdb.h,v 1.15.18.6 2006/10/02 01:23:09 marka Exp $
  */
 
 #ifndef _NETDB_H_
@@ -131,99 +131,98 @@ __END_DECLS
 extern int h_errno;
 #endif
 
-/*
+/*%
  * Structures returned by network data base library.  All addresses are
  * supplied in host order, and returned in network order (suitable for
  * use in system calls).
  */
 struct	hostent {
-	char	*h_name;	/* official name of host */
-	char	**h_aliases;	/* alias list */
-	int	h_addrtype;	/* host address type */
-	int	h_length;	/* length of address */
-	char	**h_addr_list;	/* list of addresses from name server */
-#define	h_addr	h_addr_list[0]	/* address, for backward compatiblity */
+	char	*h_name;	/*%< official name of host */
+	char	**h_aliases;	/*%< alias list */
+	int	h_addrtype;	/*%< host address type */
+	int	h_length;	/*%< length of address */
+	char	**h_addr_list;	/*%< list of addresses from name server */
+#define	h_addr	h_addr_list[0]	/*%< address, for backward compatiblity */
 };
 
-/*
+/*%
  * Assumption here is that a network number
  * fits in an unsigned long -- probably a poor one.
  */
 struct	netent {
-	char		*n_name;	/* official name of net */
-	char		**n_aliases;	/* alias list */
-	int		n_addrtype;	/* net address type */
-	unsigned long	n_net;		/* network # */
+	char		*n_name;	/*%< official name of net */
+	char		**n_aliases;	/*%< alias list */
+	int		n_addrtype;	/*%< net address type */
+	unsigned long	n_net;		/*%< network # */
 };
 
 struct	servent {
-	char	*s_name;	/* official service name */
-	char	**s_aliases;	/* alias list */
-	int	s_port;		/* port # */
-	char	*s_proto;	/* protocol to use */
+	char	*s_name;	/*%< official service name */
+	char	**s_aliases;	/*%< alias list */
+	int	s_port;		/*%< port # */
+	char	*s_proto;	/*%< protocol to use */
 };
 
 struct	protoent {
-	char	*p_name;	/* official protocol name */
-	char	**p_aliases;	/* alias list */
-	int	p_proto;	/* protocol # */
+	char	*p_name;	/*%< official protocol name */
+	char	**p_aliases;	/*%< alias list */
+	int	p_proto;	/*%< protocol # */
 };
 
 struct	addrinfo {
-	int		ai_flags;	/* AI_PASSIVE, AI_CANONNAME */
-	int		ai_family;	/* PF_xxx */
-	int		ai_socktype;	/* SOCK_xxx */
-	int		ai_protocol;	/* 0 or IPPROTO_xxx for IPv4 and IPv6 */
+	int		ai_flags;	/*%< AI_PASSIVE, AI_CANONNAME */
+	int		ai_family;	/*%< PF_xxx */
+	int		ai_socktype;	/*%< SOCK_xxx */
+	int		ai_protocol;	/*%< 0 or IPPROTO_xxx for IPv4 and IPv6 */
 #if defined(sun) && defined(_SOCKLEN_T)
-#ifdef __sparc9
+#ifdef __sparcv9
 	int		_ai_pad;
 #endif
 	socklen_t	ai_addrlen;
 #else
-	size_t		ai_addrlen;	/* length of ai_addr */
+	size_t		ai_addrlen;	/*%< length of ai_addr */
 #endif
 #ifdef __linux
-	struct sockaddr	*ai_addr; 	/* binary address */
-	char		*ai_canonname;	/* canonical name for hostname */
+	struct sockaddr	*ai_addr; 	/*%< binary address */
+	char		*ai_canonname;	/*%< canonical name for hostname */
 #else
-	char		*ai_canonname;	/* canonical name for hostname */
-	struct sockaddr	*ai_addr; 	/* binary address */
+	char		*ai_canonname;	/*%< canonical name for hostname */
+	struct sockaddr	*ai_addr; 	/*%< binary address */
 #endif
-	struct addrinfo	*ai_next; 	/* next structure in linked list */
+	struct addrinfo	*ai_next; 	/*%< next structure in linked list */
 };
 
-/*
+/*%
  * Error return codes from gethostbyname() and gethostbyaddr()
  * (left in extern int h_errno).
  */
 
-#define	NETDB_INTERNAL	-1	/* see errno */
-#define	NETDB_SUCCESS	0	/* no problem */
-#define	HOST_NOT_FOUND	1 /* Authoritative Answer Host not found */
-#define	TRY_AGAIN	2 /* Non-Authoritive Host not found, or SERVERFAIL */
-#define	NO_RECOVERY	3 /* Non recoverable errors, FORMERR, REFUSED, NOTIMP */
-#define	NO_DATA		4 /* Valid name, no data record of requested type */
-#define	NO_ADDRESS	NO_DATA		/* no address, look for MX record */
-
+#define	NETDB_INTERNAL	-1	/*%< see errno */
+#define	NETDB_SUCCESS	0	/*%< no problem */
+#define	HOST_NOT_FOUND	1 /*%< Authoritative Answer Host not found */
+#define	TRY_AGAIN	2 /*%< Non-Authoritive Host not found, or SERVERFAIL */
+#define	NO_RECOVERY	3 /*%< Non recoverable errors, FORMERR, REFUSED, NOTIMP */
+#define	NO_DATA		4 /*%< Valid name, no data record of requested type */
+#define	NO_ADDRESS	NO_DATA		/*%< no address, look for MX record */
 /*
  * Error return codes from getaddrinfo()
  */
-#define	EAI_ADDRFAMILY	 1	/* address family for hostname not supported */
-#define	EAI_AGAIN	 2	/* temporary failure in name resolution */
-#define	EAI_BADFLAGS	 3	/* invalid value for ai_flags */
-#define	EAI_FAIL	 4	/* non-recoverable failure in name resolution */
-#define	EAI_FAMILY	 5	/* ai_family not supported */
-#define	EAI_MEMORY	 6	/* memory allocation failure */
-#define	EAI_NODATA	 7	/* no address associated with hostname */
-#define	EAI_NONAME	 8	/* hostname nor servname provided, or not known */
-#define	EAI_SERVICE	 9	/* servname not supported for ai_socktype */
-#define	EAI_SOCKTYPE	10	/* ai_socktype not supported */
-#define	EAI_SYSTEM	11	/* system error returned in errno */
+#define	EAI_ADDRFAMILY	 1	/*%< address family for hostname not supported */
+#define	EAI_AGAIN	 2	/*%< temporary failure in name resolution */
+#define	EAI_BADFLAGS	 3	/*%< invalid value for ai_flags */
+#define	EAI_FAIL	 4	/*%< non-recoverable failure in name resolution */
+#define	EAI_FAMILY	 5	/*%< ai_family not supported */
+#define	EAI_MEMORY	 6	/*%< memory allocation failure */
+#define	EAI_NODATA	 7	/*%< no address associated with hostname */
+#define	EAI_NONAME	 8	/*%< hostname nor servname provided, or not known */
+#define	EAI_SERVICE	 9	/*%< servname not supported for ai_socktype */
+#define	EAI_SOCKTYPE	10	/*%< ai_socktype not supported */
+#define	EAI_SYSTEM	11	/*%< system error returned in errno */
 #define EAI_BADHINTS	12
 #define EAI_PROTOCOL	13
 #define EAI_MAX		14
 
-/*
+/*%
  * Flag values for getaddrinfo()
  */
 #define	AI_PASSIVE	0x00000001
@@ -231,7 +230,7 @@ struct	addrinfo {
 #define AI_NUMERICHOST	0x00000004
 #define	AI_MASK		0x00000007
 
-/*
+/*%
  * Flag values for getipnodebyname()
  */
 #define AI_V4MAPPED	0x00000008
@@ -239,13 +238,13 @@ struct	addrinfo {
 #define AI_ADDRCONFIG	0x00000020
 #define AI_DEFAULT	(AI_V4MAPPED|AI_ADDRCONFIG)
 
-/*
+/*%
  * Constants for getnameinfo()
  */
 #define	NI_MAXHOST	1025
 #define	NI_MAXSERV	32
 
-/*
+/*%
  * Flag values for getnameinfo()
  */
 #define	NI_NOFQDN	0x00000001
@@ -256,7 +255,7 @@ struct	addrinfo {
 #define	NI_WITHSCOPEID	0x00000020
 #define NI_NUMERICSCOPE	0x00000040
 
-/*
+/*%
  * Scope delimit character
  */
 #define SCOPE_DELIMITER	'%'
@@ -291,7 +290,7 @@ struct hostent_data {
 
 struct  netent_data {
 	FILE	*net_fp;
-#ifdef __osf__
+#if defined(__osf__) || defined(_AIX)
 	char	line[_MAXLINELEN];
 #endif
 #ifdef __hpux
@@ -308,10 +307,21 @@ struct  netent_data {
 	char	*current;
 	int	currentlen;
 #endif
+#ifdef _AIX
+        int     _net_stayopen;
+        char    *current;
+        int     currentlen;
+        void    *_net_reserv1;          /* reserved for future use */
+        void    *_net_reserv2;          /* reserved for future use */
+#endif
 };
 
 struct	protoent_data {
 	FILE	*proto_fp;
+#ifdef _AIX
+	int     _proto_stayopen;
+	char	line[_MAXLINELEN];
+#endif
 #ifdef __osf__
 	char	line[1024];
 #endif
@@ -329,11 +339,17 @@ struct	protoent_data {
 	char	*current;
 	int	currentlen;
 #endif
+#ifdef _AIX
+        int     currentlen;
+        char    *current;
+        void    *_proto_reserv1;        /* reserved for future use */
+        void    *_proto_reserv2;        /* reserved for future use */
+#endif
 };
 
 struct	servent_data {
 	FILE	*serv_fp;
-#ifdef __osf__
+#if defined(__osf__) || defined(_AIX)
 	char	line[_MAXLINELEN];
 #endif
 #ifdef __hpux
@@ -350,6 +366,13 @@ struct	servent_data {
 	char	*current;
 	int	currentlen;
 #endif
+#ifdef _AIX
+	int     _serv_stayopen;
+	char     *current;
+	int     currentlen;
+	void    *_serv_reserv1;         /* reserved for future use */
+	void    *_serv_reserv2;         /* reserved for future use */
+#endif
 };
 #endif
 #endif
@@ -457,9 +480,19 @@ int		endservent_r __P((struct servent_data *));
 #else
 void		endservent_r __P((struct servent_data *));
 #endif
+#ifdef _AIX
+int		setnetgrent_r __P((const char *, void **));
+void		endnetgrent_r __P((void **));
+/*
+ * Note: AIX's netdb.h declares innetgr_r() as: 
+ *	int innetgr_r(char *, char *, char *, char *, struct innetgr_data *);
+ */
+int		innetgr_r __P((const char *, const char *, const char *,
+			       const char *));
+#endif
 #else
  /* defined(sun) || defined(bsdi) */
-#ifdef __GLIBC__
+#if defined(__GLIBC__) || defined(__FreeBSD__) && (__FreeBSD_version + 0 >= 601103)
 int gethostbyaddr_r __P((const char *, int, int, struct hostent *,
 		         char *, size_t, struct hostent **, int *));
 int gethostbyname_r __P((const char *, struct hostent *,
@@ -476,7 +509,7 @@ struct hostent	*gethostent_r __P((struct hostent *, char *, int, int *));
 void		sethostent_r __P((int));
 void		endhostent_r __P((void));
 
-#ifdef __GLIBC__
+#if defined(__GLIBC__) || defined(__FreeBSD__) && (__FreeBSD_version + 0 >= 601103)
 int getnetbyname_r __P((const char *, struct netent *,
 			char *, size_t, struct netent **, int*));
 int getnetbyaddr_r __P((unsigned long int, int, struct netent *,
@@ -492,7 +525,7 @@ struct netent	*getnetent_r __P((struct netent *, char *, int));
 void		setnetent_r __P((int));
 void		endnetent_r __P((void));
 
-#ifdef __GLIBC__
+#if defined(__GLIBC__) || defined(__FreeBSD__) && (__FreeBSD_version + 0 >= 601103)
 int getprotobyname_r __P((const char *, struct protoent *, char *,
 			  size_t, struct protoent **));
 int getprotobynumber_r __P((int, struct protoent *, char *, size_t,
@@ -508,7 +541,7 @@ struct protoent	*getprotoent_r __P((struct protoent *, char *, int));
 void		setprotoent_r __P((int));
 void		endprotoent_r __P((void));
 
-#ifdef __GLIBC__
+#if defined(__GLIBC__) || defined(__FreeBSD__) && (__FreeBSD_version + 0 >= 601103)
 int getservbyname_r __P((const char *name, const char *,
 			 struct servent *, char *, size_t, struct servent **));
 int getservbyport_r __P((int port, const char *,
@@ -527,9 +560,6 @@ void		endservent_r __P((void));
 #ifdef __GLIBC__
 int		getnetgrent_r __P((char **, char **, char **, char *, size_t));
 #endif
-#ifdef _AIX
-int		setnetgrent_r __P((char *, void **));
-#endif
 
 #endif
 #endif
@@ -541,12 +571,12 @@ __END_DECLS
 #include <rpc/netdb.h>
 #else
 struct rpcent {
-	char	*r_name;	/* name of server for this rpc program */
-	char	**r_aliases;	/* alias list */
-	int	r_number;	/* rpc program number */
+	char	*r_name;	/*%< name of server for this rpc program */
+	char	**r_aliases;	/*%< alias list */
+	int	r_number;	/*%< rpc program number */
 };
 struct rpcent	*getrpcbyname(), *getrpcbynumber(), *getrpcent();
 #endif /* __GNU_LIBRARY__ */
 #endif /* sun */
-
 #endif /* !_NETDB_H_ */
+/*! \file */
